Introduction
============

:mod:`ndfilters` is an experimental library designed to parallelize the filters in
:mod:`scipy.ndimage` using the `Numba <https://numba.readthedocs.io/en/stable/>`_
just-in-time compiler.


Installation
============
:mod:`ndfilters` is published on PyPI and can be installed using::

    pip install ndfilters


API Reference
=============

.. autosummary::
    :toctree: _autosummary
    :template: module_custom.rst
    :recursive:

    ndfilters



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
